@@ -1,11 +1,6 @@
-"""
-a Python NATS client
+"""a Python NATS client"""
 
->>> from goingnats import Client, one
-
-Check if __name__ == "__main__" for full example
-"""
-__version__ = "2021.4.0"
+__version__ = "2022.3.0"
 
 import json
 import queue
@@ -69,7 +64,7 @@ class Client:
                 ]
             )
         except TypeError:
-            raise TypeError("subject and payload must be bytes-like")
+            raise TypeError("subject and payload must be bytes-like") from None
 
     def subscribe(self, *, subject):
         """subscribe to subject"""
@@ -77,9 +72,9 @@ class Client:
         try:
             self._send([b"SUB", SPACE, subject, SPACE, _int_to_bytes(self._sid)])
         except TypeError:
-            raise TypeError("subject must be bytes-like")
+            raise TypeError("subject must be bytes-like") from None
 
-    def request(self, *, subject, payload=""):
+    def request(self, *, subject, payload=b""):
         """request subject for a response to payload"""
         inbox = f"INBOX.{uuid.uuid4().hex}".encode()
         self._sid += 1
@@ -100,7 +95,7 @@ class Client:
                 ]
             )
         except TypeError:
-            raise TypeError("subject and payload must be bytes-like")
+            raise TypeError("subject and payload must be bytes-like") from None
         return self._response.get()
 
     def __enter__(self):
